package com.qianhe.service;

import com.qianhe.domain.JygxWzgl;
import com.qianhe.domain.Jyjl;
import com.qianhe.domain.Ssfl;

import java.util.List;


/**
 * 经验共享-文章管理Service接口
 *
 * @author qianhe
 * @date 2024-07-29
 */
public interface IJygxWzglService
{
    /**
     * 查询经验共享-文章管理
     *
     * @param wzid 经验共享-文章管理主键
     * @return 经验共享-文章管理
     */
    public JygxWzgl selectJygxWzglByWzid(Long wzid);

    /**
     * 查询经验共享-文章管理
     *
     * @param wzid 经验共享-文章管理主键
     * @return 经验共享-文章管理
     */
    public JygxWzgl selectsyWzid(Long wzid);

    /**
     * 查询经验共享-文章管理列表
     *
     * @param jygxWzgl 经验共享-文章管理
     * @return 经验共享-文章管理集合
     */
    public List<JygxWzgl> selectJygxWzglList(JygxWzgl jygxWzgl);

    /**
     * 查询经验共享-文章管理列表
     *
     * @param jygxWzgl 经验共享-文章管理
     * @return 经验共享-文章管理集合
     */
    public List<JygxWzgl> selectList(JygxWzgl jygxWzgl);

    /**
     * 查询经验共享-首页轮播图新闻
     *
     * @param jygxWzgl
     * @return
     */
    public List<JygxWzgl> selectSylbxwList(JygxWzgl jygxWzgl);

    /**
     * 新增经验共享-文章管理
     *
     * @param jygxWzgl 经验共享-文章管理
     * @return 结果
     */
    public int insertJygxWzgl(JygxWzgl jygxWzgl);

    /**
     * 新增首页轮播新闻
     */
    public int insertxw(JygxWzgl jygxWzgl);

    /**
     * 修改经验共享-文章管理
     *
     * @param jygxWzgl 经验共享-文章管理
     * @return 结果
     */
    public int updateJygxWzgl(JygxWzgl jygxWzgl);


    /**
     * 提交
     */
    public int updatetj(JygxWzgl jygxWzgl);

    /**
     * 批量删除经验共享-文章管理
     *
     * @param wzids 需要删除的经验共享-文章管理主键集合
     * @return 结果
     */
    public int deleteJygxWzglByWzids(Long[] wzids);

    /**
     * 删除经验共享-文章管理信息
     *
     * @param wzid 经验共享-文章管理主键
     * @return 结果
     */
    public int deleteJygxWzglByWzid(Long wzid);

    /**
     * 数据置顶
     */
    public int updatewzzd(JygxWzgl jygxWzgl);


    /**
     * 取消置顶
     */
    public int updateqxzd(JygxWzgl jygxWzgl);

    /**
     * 首页搜索类型条数
     */
    public List<Ssfl> selectcxflList(JygxWzgl jygxWzgl);

    /**
     * 首页搜索类型条数
     */
    public List<JygxWzgl> selectsyssList(JygxWzgl jygxWzgl);

    /**
     * 首页搜索类型条数
     */
    public List<Jyjl> selectjyjlList();
}
